use std::fs;

use pest::Parser;
use pest_derive::Parser;

#[derive(Parser)]
#[grammar = "csv.pest"]
struct CSVParser;

pub fn parse(file_path: &str) {
    let unparsed_file = fs::read_to_string(file_path).expect("cannot find file");
    let file = CSVParser::parse(Rule::file, &unparsed_file)
        .expect("unsuccessful parse") // unwrap the parse result
        .next().unwrap(); // get and unwrap the `file` rule; never fails

    let mut field_sum = 0.0;
    let mut record_count: u64 = 0;

    for record in file.into_inner() {
        match record.as_rule() {
            Rule::record => {
                record_count += 1;

                for field in record.into_inner() {
                    field_sum += field.as_str().parse::<f64>().unwrap();
                }
            },
            Rule::EOI => (),
            _ => unreachable!(),
        }
    }

    println!("Sum of fields: {field_sum}");
    println!("Number of records: {record_count}");
}
